{- This file is part of irc-fun-client.
 -
 - Written in 2015 by fr33domlover <fr33domlover@rel4tion.org>.
 -
 - ♡ Copying is an act of love. Please copy, reuse and share.
 -
 - The author(s) have dedicated all copyright and related and neighboring
 - rights to this software to the public domain worldwide. This software is
 - distributed without any warranty.
 -
 - You should have received a copy of the CC0 Public Domain Dedication along
 - with this software. If not, see
 - <http://creativecommons.org/publicdomain/zero/1.0/>.
 -}

-- | Here is an overview of the library, by module:
--
-- * "IO": Provides functions for connecting to an IRC server, and for sending
--   and receiving IRC messages.
-- * "Commands": Provides functions for sending IRC commands to the server.
-- * "Events": Provides an Event type and functions for receiving IRC events.
--   These events are an abstraction on top of IRC messages.
-- * "Util": Miscellaneous helper functions which could be useful to clients
--
-- If you're writing an IRC client, here is a suggestion for how to begin:
--
-- (1) Use functions from "IO" module to connect to an IRC server
-- (2) Use functions from "Commands" module to send common IRC commands
-- (3) Write an events loop which listens to the IRC server input and responds,
--     and a UI component which reacts to user-initiated commands. Use the
--     "Events" module to receive high-level events. If you have a specific
--     need to receive IRC messages directly, use functions from the "IO"
--     module.
module Network.IRC.Fun.Client
    ( module Network.IRC.Fun.Client.Commands
    , module Network.IRC.Fun.Client.Events
    , module Network.IRC.Fun.Client.IO
    , module Network.IRC.Fun.Client.Util
    )
where

import Network.IRC.Fun.Client.Commands
import Network.IRC.Fun.Client.Events
import Network.IRC.Fun.Client.IO
import Network.IRC.Fun.Client.Util
